import { StoreParams } from '../filelink';
import { ClientOptions, Session } from '../client';
import { UploadTags } from './upload/file';
/**
 * @private
 */
export declare const PICKER_KEY = "__fs_picker_token";
/**
 * key for picker callback url (specifies which tab will be opened after opening picker)
 * @private
 */
export declare const CALLBACK_URL_KEY = "fs-tab";
/**
 * @private
 */
export declare class CloudClient {
    session: Session;
    cloudApiUrl: string;
    /**
     * Returns flag if token should be cached in local storage
     *
     * @private
     * @type {boolean}
     * @memberof CloudClient
     */
    private cache;
    /**
     * Token returned from api for accessing clouds
     *
     * @private
     * @type {string}
     * @memberof CloudClient
     */
    private _token;
    /**
     * Store adapter instance
     *
     * @private
     * @type {Store}
     * @memberof CloudClient
     */
    private storeAdapter;
    constructor(session: Session, options?: ClientOptions);
    get token(): string;
    set token(key: string);
    /**
     * Return information is inappbrowser flag is set
     *
     * @readonly
     * @memberof CloudClient
     */
    private get isInAppBrowser();
    list(clouds: any, cancelTokenInput?: any, accept?: string[] | string): Promise<any>;
    store(name: string, path: string, options?: StoreParams, customSource?: any, cancelTokenInput?: any, uploadTags?: UploadTags): Promise<any>;
    logout(name?: string): Promise<any>;
    metadata(url: string, headers?: {
        [key: string]: string;
    }): Promise<any>;
    tokInit(type: string): Promise<any>;
    tokStart(type: string, key: string, sessionId: string): Promise<any>;
    tokStop(type: string, key: string, sessionId: string, archiveId: string): Promise<any>;
    private currentAppUrl;
}
