import { Security } from '../client';
import { WebhookValidatePayload, SecurityOptions } from './security';
/**
 * Returns Filestack base64 policy and HMAC-SHA256 signature
 *
 * ### Example
 *
 * ```js
 * import * as filestack from 'filestack-js';
 *
 * const jsonPolicy = { 'expiry': 253381964415 };
 * const security = filestack.getSecurity(jsonPolicy, '<YOUR_APP_SECRET>');
 * ```
 *
 * @param policyOptions
 * @param appSecret
 */
export declare const getSecurity: (policyOptions: SecurityOptions, appSecret: string) => Security;
/**
 * Check webhook signature
 *
 * @param secret - app secred
 * @param rawBody - unchanged raw webhook body
 * @param toCompare - data from wh response headers
 */
export declare const validateWebhookSignature: (secret: string, rawBody: string, toCompare: WebhookValidatePayload) => boolean;
